ExArrow.IPC.Writer (ex_arrow v0.4.0)

IPC stream/file writer: write Arrow record batches to binary or file.

Summary

Functions

Writes record batches (as a stream or list) to a binary. Batches must share the same schema.

Writes record batches to a file at the given path.

Functions

to_binary(schema, batches)

@spec to_binary(ExArrow.Schema.t(), [ExArrow.RecordBatch.t()] | Enumerable.t()) ::
  {:ok, binary()} | {:error, String.t()}

Writes record batches (as a stream or list) to a binary. Batches must share the same schema.

to_file(path, schema, batches)

@spec to_file(
  Path.t(),
  ExArrow.Schema.t(),
  [ExArrow.RecordBatch.t()] | Enumerable.t()
) ::
  :ok | {:error, String.t()}

Writes record batches to a file at the given path.